use std::path::PathBuf;

use super::release_manager::models::ArtifactID;

pub mod extensions;

#[derive(Clone)]
pub struct FileStore {
    client: aws_sdk_s3::Client,
}

use aws_sdk_s3::primitives::ByteStream;
#[cfg(test)]
use mockall::{automock, mock, predicate::*};
use tokio::io::AsyncReadExt;

#[cfg_attr(test, automock)]
impl FileStore {
    pub fn new(client: aws_sdk_s3::Client) -> Self {
        Self { client }
    }

    pub async fn upload_file(&self, artifact_id: ArtifactID, file: PathBuf) -> anyhow::Result<()> {
        tracing::trace!("uploading files: {}", artifact_id.to_string());

        self.client
            .put_object()
            .bucket("mybucket")
            .key(format!("archives/{}.tar", &artifact_id.to_string()))
            .body(ByteStream::from_path(file).await?)
            .send()
            .await?;

        Ok(())
    }
}
